-- ----------------------------------------------------------------------------
--  Salvage Crates
-- 		by Nasapunk88
-- ----------------------------------------------------------------------------

SalvageCrates = {};
SalvageCratesDB = SalvageCratesDB or {["enable"] = true,};

SalvageCrates.items = {
	{ ["name"] = "SalvageCrates_BagButton",  --"Bag of Salvaged Goods"
	  ["id"] = 114116, 
	  ["button"] = nil
	},
	{ ["name"] = "SalvageCrates_CrateButton", --"Crate of Salvage"
	  ["id"] = 114119,
	  ["button"] = nil
	},
	{ ["name"] = "SalvageCrates_BigCrateButton", --"Big Crate of Salvage"
	  ["id"] = 114120,
	  ["button"] = nil
	}
};

function SalvageCrates:updateButtons()
	if SalvageCratesDB.enable  then
		self.frame:Show();
		for i = 1, #self.items do
			self:updateButton(self.items[i].button,self.items[i].id,i);
		end
	else
		self.frame:Hide();
	end
end

function SalvageCrates:updateButton(btn,id,num)
	local count = GetItemCount(id);
	if count > 0 then
		--Move button to the right of the previous button
		if self.previous == 0 then
			btn:SetPoint("LEFT", self.frame, "LEFT", 0, 0);
		else
			btn:SetPoint("LEFT", self.items[self.previous].button, "RIGHT", 0, 0);
		end
		self.previous = num;
		btn.countString:SetText(format("%d",count));
		btn.texture:SetDesaturated(false);
		btn:Show();
	elseif count == 0 then
		btn.countString:SetText("");
		btn.texture:SetDesaturated(true);
		btn:Hide();
	end
end

function SalvageCrates:createButton(btn,id)
	btn:Hide();
	btn:SetWidth(40);
	btn:SetHeight(40);
	btn:ClearAllPoints();
	btn:SetClampedToScreen(true);
	btn:SetPoint("LEFT", self.frame, "LEFT", 0, 0);
	--Right click to drag
	btn:EnableMouse(true);
	btn:RegisterForDrag("RightButton");
	btn:SetMovable(true);
	btn:SetScript("OnDragStart", function(self) self:GetParent():StartMoving(); end);
	btn:SetScript("OnDragStop", function(self) 
			self:GetParent():StopMovingOrSizing();
			self:GetParent():SetUserPlaced(false);
			local point, relativeTo, relativePoint, xOfs, yOfs = self:GetParent():GetPoint();
			SalvageCratesDB.position = {point, nil, relativePoint, xOfs, yOfs};
		end);
	--Setup macro
	btn:SetAttribute("type", "macro");
	btn:SetAttribute("macrotext", format("/use item:%d",id));
	btn.countString = btn:CreateFontString(btn:GetName().."Count", "OVERLAY", "NumberFontNormal");
	btn.countString:SetPoint("BOTTOMRIGHT", btn, -3, 2);
	btn.countString:SetJustifyH("RIGHT");
	btn.icon = btn:CreateTexture(nil,"BACKGROUND");
	btn.icon:SetTexture(GetItemIcon(id));
	btn.icon:SetAllPoints(btn);
	btn.texture = btn.icon;
	--Tooltip
	btn:SetScript("OnEnter", function(self)
		GameTooltip:SetOwner(self,"ANCHOR_TOP");
		GameTooltip:SetItemByID(format("%d",id));
		GameTooltip:SetClampedToScreen(true);
		GameTooltip:Show();
	  end);
	btn:SetScript("OnLeave",GameTooltip_Hide);
 end
 
function SalvageCrates:OnEvent(event, ...)
	--Check for combat to avoid tainting frame
	if UnitAffectingCombat("player") then
		return
	end
	--Only load buttons when player is in their Salvage Yard
	if not IsInInstance() and GetMinimapZoneText() == "Salvage Yard"  then
		self.frame:RegisterEvent("BAG_UPDATE");
		self.frame:Show();
		self.previous = 0;
		SalvageCrates:updateButtons();
	else --Hide anywhere else
		self.frame:Hide();
		self.frame:UnregisterEvent("BAG_UPDATE"); 
	end
end

------------------------------------------------
-- Slash Commands
------------------------------------------------
local function slashHandler(msg)
	msg = msg:lower() or "";
	if (msg == "show" or msg == "enable") then
		SalvageCratesDB.enable = true;
		SalvageCrates:updateButtons();
		print("|cff33ff99Salvage Crates|r: Enabled");
	elseif (msg == "hide" or msg == "disable") then
		SalvageCratesDB.enable = false;
		SalvageCrates:updateButtons();
		print("|cff33ff99Salvage Crates|r: Disabled");
	else
		print("|cff33ff99Salvage Crates|r: Arguments to |cffffff78/SalvageCrates|r :");
		print("  |cffffff78 show|r - Show the buttons.");
		print("  |cffffff78 hide|r - Hide the buttons.");
	end
end

SlashCmdList.SalvageCrates = function(msg) slashHandler(msg) end;
SLASH_SalvageCrates1 = "/SalvageCrates";

--Helper functions
local function cout(msg, premsg)
	premsg = premsg or "[".."Salvage Crates".."]"
	print("|cFFE8A317"..premsg.."|r "..msg);
end

local function coutBool(msg,bool)
	if bool then
		print(msg..": true");
	else
		print(msg..": false");
	end
end

--Main Frame
SalvageCrates.frame = CreateFrame("Frame", "SalvageCrates_Frame", UIParent);
SalvageCrates.frame:Hide();
SalvageCrates.frame:SetWidth(79);
SalvageCrates.frame:SetHeight(39);
SalvageCrates.frame:SetClampedToScreen(true);
SalvageCrates.frame:SetFrameStrata("BACKGROUND");
SalvageCrates.frame:SetMovable(true);
SalvageCrates.frame:RegisterEvent("ZONE_CHANGED");
SalvageCrates.frame:RegisterEvent("PLAYER_ENTERING_WORLD");
SalvageCrates.frame:RegisterEvent("PLAYER_REGEN_ENABLED"); 
SalvageCrates.frame:SetScript("OnEvent", function(self,event,...) SalvageCrates:OnEvent(event,...) end);
SalvageCrates.frame:SetScript("OnShow", function(self,event,...) 
	--Restore position
	if SalvageCratesDB and SalvageCratesDB.position then
		self:SetPoint(SalvageCratesDB.position[1],UIParent,SalvageCratesDB.position[3],SalvageCratesDB.position[4],SalvageCratesDB.position[5]);
	else
		self:SetPoint('CENTER', UIParent, 'CENTER', 0, 0);
	end
 end);
---Create button for each item
for i = 1, #SalvageCrates.items do
	SalvageCrates.items[i].button = CreateFrame("Button", SalvageCrates.items[i].name, SalvageCrates.frame, "SecureActionButtonTemplate,ActionButtonTemplate");
	SalvageCrates:createButton(SalvageCrates.items[i].button,SalvageCrates.items[i].id);
end